# yaol-utils
Python package for various utility functions

Create distribution by running

`python setup.py sdist bdist_wheel`.

The upload the distribution to pypi by calling+

`twine upload dist/*`.